# Change Log
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).

## [0.1.0] - 2021-08-24

Initial cli

### Added

### Changed

### Fixed
Hashing order guarantees the right index of the query.json file in the hash
